@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponseWriter.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: ApacheResponseWriter.cpp 2883 2008-05-02 12:59:25Z svn $
  *****************************************************************************/
 
 // Apache の config.h を先に処理させるため，util_filter.h の
@@ -43,7 +43,7 @@
 #include "ApacheResponseWriter.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ApacheResponseWriter.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: ApacheResponseWriter.cpp 2883 2008-05-02 12:59:25Z svn $");
 
 ////////// Apache 1.x 用 //////////////////////////////////////////////
 #if AP_SERVER_MAJORVERSION_NUMBER == 1
@@ -113,7 +113,7 @@ void ApacheResponseWriter::flush()
 
     for (apr_size_t i = 0; i < iovec_count_; i++) {
         ap_rwrite(iovec_[i].iov_base,
-                  iovec_[i].iov_len,
+                  static_cast<int>(iovec_[i].iov_len),
                   reinterpret_cast<ApacheResponse::Handle *>(brigade_)->r); // :-)
     }
 
