@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ImageFile.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: ImageFile.cpp 2882 2008-05-02 12:28:05Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -54,7 +54,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: ImageFile.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: ImageFile.cpp 2882 2008-05-02 12:28:05Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -101,12 +101,12 @@ void ImageFile::create_thumbnail(const char *file_path,
 
 apr_uint16_t ImageFile::get_width() const
 {
-    return image_->size().width();
+    return static_cast<apr_uint16_t>(image_->size().width());
 }
 
 apr_uint16_t ImageFile::get_height() const
 {
-    return image_->size().height();
+    return static_cast<apr_uint16_t>(image_->size().height());
 }
 
 
