@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.cpp 2882 2008-05-02 12:28:05Z svn $
+ * $Id: mod_uploader.cpp 2894 2008-07-15 16:29:54Z svn $
  *****************************************************************************/
 
 /**
@@ -65,7 +65,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: mod_uploader.cpp 2882 2008-05-02 12:28:05Z svn $");
+SOURCE_INFO_ADD("$Id: mod_uploader.cpp 2894 2008-07-15 16:29:54Z svn $");
 
 static const char *HANDLER_NAME = "uploader";
 static apr_array_header_t *uploader_config_array = NULL;
@@ -248,7 +248,9 @@ static int uploader_post_config_server(apr_pool_t *p, server_rec *s)
                                       apr_pool_cleanup_null);
         } catch(const char *message) {
             logger.error(__FILE__, __LINE__, s,
-                         "(%s) %s", "UploaderConfig::init", message);
+                         "(%s) %s: %s", "UploaderConfig::init", message,
+                         get_last_error_message(p));
+
             return HTTP_INTERNAL_SERVER_ERROR;
         }
     }
@@ -351,7 +353,7 @@ static int uploader_handler(request_rec *r)
 
 static const handler_rec uploader_handlers[] = {
     { HANDLER_NAME, uploader_handler },
-    { NULL }
+    { NULL, NULL }
 };
 
 ////////// Apache 2.x 用 //////////////////////////////////////////////
@@ -431,7 +433,7 @@ static const command_rec uploader_cmds[] = {
     DIRECTIVE_ENTRY(THUMBNAIL_VIEW_TEMPLATE, THUMBNAIL_VIEW),
     DIRECTIVE_ENTRY(ADMIN_VIEW_TEMPLATE, ADMIN_VIEW),
     DIRECTIVE_ENTRY(ERROR_VIEW_TEMPLATE, ERROR_VIEW),
-    { NULL }
+    { NULL, NULL, NULL, 0, TAKE1, NULL }
 };
 
 extern "C" {
