@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2880 2008-05-01 12:19:40Z svn $
+ * $Id: uploader_handler.cpp 2894 2008-07-15 16:29:54Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -57,7 +57,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2880 2008-05-01 12:19:40Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2894 2008-07-15 16:29:54Z svn $");
 #endif
 
 #define STR_CMP_LITERAL(arg, literal)                            \
@@ -306,8 +306,6 @@ static int sort(typename Response::Handle *r, UploaderConfig *config,
 
     cmp_func = get_sort_func(sort_type);
     if (cmp_func == NULL) {
-        std::cout << "sort_type: " << sort_type << std::endl;
-        std::cerr << "sort_type: " << sort_type << std::endl;
         return index<Response>(r, config, arg);
     }
 
@@ -847,11 +845,7 @@ template<class Response>
 static int download_set_header(typename Response::Handle *r, UploadItem *uitem,
                                apr_file_t *item_file)
 {
-#ifdef UPLOADER_TYPE_APACHE
-    Response::set_content_type(r);
-#else
-    Response::set_content_type(r, uitem->get_file_mime());
-#endif
+    Response::set_content_type(r, uitem->get_file_mime(), true);
 
 #ifdef UPLOADER_TYPE_APACHE
 #if AP_SERVER_MAJORVERSION_NUMBER != 1
