@@ -77,7 +77,7 @@ sub get_release_links {
 
     $self->_mv_list_release_page();
 
-    @links = grep($_->url() =~ m|\Qhttp://prdownloads.\E|,
+    @links = grep($_->url() =~ m|/projects/[^/]+/downloads|,
                   $self->{'mech'}->find_all_links());
 
     map { $_->[0] }
